from base64 import b64decode


def base64_to_file(content, file_path):
    f = open(file_path, "wb")

    try:
        f.write(content.decode('base64'))  # python 2
    except AttributeError:
        f.write(b64decode(content))  # python 3

    f.close()



import hashlib
import random
import unicodedata
from base64 import b64encode
from datetime import datetime
from io import BytesIO


def generate_hash(length=5):
    salt = str(random.random())
    pepper = str(datetime.now())
    soup = (salt + pepper).encode('utf-8')
    return hashlib.sha1(soup).hexdigest()[:length]


def barcode(code, args=None):
    options = dict()
    if args is not None:
        arguments = args.split(',')
        for arg_pair in arguments:
            key, value = arg_pair.split('=')
            options[key] = int(value)

    from python_pragmatic.thirdparty import BarcodeImageWriter

    import barcode
    output = BytesIO()

    barcode.Code39(code=code,
                   # writer=ImageWriter(),  # has bottom padding
                   writer=BarcodeImageWriter(),  # removes bottom padding
                   add_checksum=False)\
        .write(output, options={
            # ImageWriter options
            # 'quiet_zone': 2.5,
            # 'dpi': 300,
            # 'font_size': 30,
            # 'module_height': 7.0,
            # 'text_distance': 2

            # BarcodeImageWriter options
            'quiet_zone': 2.5,
            'dpi': 300,
            'font_size': 60,
            'module_height': 7.0,
            'text_distance': 1
        })

    code_in_bytes = output.getvalue()
    code_in_base64_bytes = b64encode(code_in_bytes)
    code_in_base_64_string = code_in_base64_bytes.decode("utf-8")
    return code_in_base_64_string


def remove_accents(input):
    """ Normalise (normalize) unicode string to remove umlauts, accents etc. """
    return unicodedata.normalize('NFKD', str(input)).encode('ASCII', 'ignore')



import datetime
from datetime import timedelta


def diff_month(date_from, date_to):
    """
    Returns number of months between dates 'date_from' and 'date_to'
    """
    return (date_to.year - date_from.year)*12 + date_to.month - date_from.month


def diff_days(date_from, date_to):
    """
    Returns number of days between dates 'date_from' and 'date_to'
    """
    return abs((date_to - date_from).days)


def week_range(date):
    """Find the first/last day of the week for the given day.
    Assuming weeks start on Sunday and end on Saturday.

    Returns a tuple of ``(start_date, end_date)``.

    """
    # isocalendar calculates the year, week of the year, and day of the week.
    # dow is Mon = 1, Sat = 6, Sun = 7
    year, week, dow = date.isocalendar()

    # Find the first day of the week.
    if dow == 7:
        # Since we want to start with Sunday, let's test for that condition.
        start_date = date
    else:
        # Otherwise, subtract `dow` number days to get the first day
        start_date = date - timedelta(dow)

    # Now, add 6 for the last day of the week (i.e., count up to Saturday)
    end_date = start_date + timedelta(6)

    #return (start_date, end_date)
    start_datetime = datetime.datetime.combine(start_date, datetime.time.min)
    end_datetime = datetime.datetime.combine(end_date, datetime.time.max)

    return start_datetime, end_datetime



import os


def load_env_from_file(env_file):
    with open(env_file) as fh:
        variables = dict(
            (line.split('=', 1)[0], line.split('=', 1)[1].rstrip("\n"))
            for line in fh.readlines() if not line.startswith('#')
        )

        for key, value in variables.items():
            os.environ[key] = value
